function u = pressure_exact(R,k,x)
%
% function u = pressure_exact(R,k,x)
%
% This function computes the exact pressure field for the problem where a point
% source is at the centre of a circle and the pressure satisfies the
% boundary condition that it is zero (equation (2.31) in the notes).
%
% On entry:
%
% R     is the radius of the circle
% k     is the wavenumber
% x     is a 2x1 vector, the position vector of the point at which the
%       pressure is required
%
% On exit:
%
% u     is the pressure at x
%
c = (i/4)*besselh(0,k*R)/besselj(0,k*R);
r = norm(x);
u = -(i/4)*besselh(0,k*r) + c*besselj(0,k*r);